==> deepin-image-viewer_5.7.4.orig.tar.xz: deepin-image-viewer-5.7.4/src/translations/deepin-image-viewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation>Visor d&apos;imatges</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>El Visor d&apos;imatges és una eina de visualització d&apos;imatges amb una interfície moderna i un rendiment eficient.</translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Imatges</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Alt+Return</source>
        <translation>Alt + Retorn</translation>
    </message>
    <message>
        <source>Alt+Enter</source>
        <translation>Alt + Retorn</translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>Informació bàsica</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalls</translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Aquest fitxer conté múltiples pàgines. Si us plau, useu l&apos;Evince per veure-les totes.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation>Obre un directori</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>No teniu permís per veure la imatge.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Suprimeix</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipus</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Data de modificació</translation>
    </message>
    <message>
        <source>Dimension</source>
        <translation>Dimensió</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Mida del fitxer</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>Data de captura</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Mode d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Programa d&apos;exposició</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Hora d&apos;exposició</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Flaix</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Obertura</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Llargada focal</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Obertura màxima</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Mode de mesura</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Balanç de blanc</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Compensació del flaix</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Model de la lent</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Espai de color</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Model de la càmera</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>Dimensions</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>Etiqueta</translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>Sense escalar</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Ajusta la pàgina a la imatge</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Ajusta la imatge a la pàgina</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Escala a:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Milímetres</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Centímetres</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Polzades</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Posició de la imatge</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Escala</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Configuració de la imatge</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation>Configuració de la imatge</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation>Persianes</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation>Commutador</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation>Lliscament</translation>
    </message>
    <message>
        <source>Ring</source>
        <translation>Anell</translation>
    </message>
    <message>
        <source>yyyy/MM/dd HH:mm:dd</source>
        <translation>dd/MM/yyyy HH:mm:dd</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>Confirmeu-ho</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancel·la</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>Escriviu un nom nou.</translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Directori seleccionat</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>Aquest directori està inhabilitat per a la sincronització.</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Afegeix una capeta</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Gestió del directori de sincronització</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>La llista de directoris és buida.</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Cancel·la la sincronització</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imatges</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>El dispositiu s&apos;ha extret.</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Aquest directori ja no existeix.</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Calculant...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualització d&apos;imatges</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Acaba la presentació</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Pantalla anterior</translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Pantalla següent</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Amplia</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Allunya</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <source>Please enter a new shortcut</source>
        <translation>Si us plau, introduïu una drecera nova.</translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <source>View Picture</source>
        <translation>Mostra la imatge</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
    <message>
        <source>Restore Defaults</source>
        <translation>Restableix els valors per defecte</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation>Visualització</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Acaba la presentació</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausa</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Reprodueix</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Surt</translation>
    </message>
</context>
<context>
    <name>SlideshowFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Paràmetres de la presentació</translation>
    </message>
    <message>
        <source>Switch effect</source>
        <translation>Efecte de canvi</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durada</translation>
    </message>
    <message>
        <source>Switch duration</source>
        <translation>Durada del canvi</translation>
    </message>
    <message>
        <source>second</source>
        <translation>segon</translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Mida 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajusta a la finestra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation>Enrere</translation>
    </message>
    <message>
        <source>Image management</source>
        <translation>Gestió de la imatge</translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation>Favorits</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>Mida 1:1</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>Ajusta a la finestra</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Obre la imatge</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>Slide Settings</source>
        <translation>Paràmetres de la presentació</translation>
    </message>
    <message>
        <source>Effect</source>
        <translation>Efecte</translation>
    </message>
    <message>
        <source>Duration</source>
        <translation>Durada</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Dreceres</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Visualitza</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Àlbum</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>New album</source>
        <translation>Àlbum nou</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation>Línia temporal</translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation>Afegeix a l&apos;àlbum</translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation>Afegeix a un àlbum nou</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>Imprimeix</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Elimina de l&apos;àlbum</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Favorit</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>No favorit</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>Mostra la finestra de navegació</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>Amaga la finestra de navegació</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Obre la imatge</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>Totes les imatges</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Draw</source>
        <translation>Dibuix</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_ca.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ca" version="2.1">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation>No s&apos;ha trobat cap fitxer d&apos;imatge.</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>Obre la imatge</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Visualització d&apos;imatges</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Configuració</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>Surt de la pantalla completa</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Extreu-ne el text</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Presentació de diapositives</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Canvia&apos;n el nom</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copia</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Gira a la dreta</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Gira a l&apos;esquerra</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Estableix com a fons d&apos;escriptori</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Mostra al gestor de fitxers</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Informació de la imatge</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Anterior</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Següent</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Amplia</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Allunya</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Obre</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Mostra les dreceres</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation>Visualitzador d&apos;imatges</translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>El Visor d&apos;imatges és una eina de visualització d&apos;imatges amb una interfície moderna i un rendiment eficient.</translation>
    </message>
</context>
</TS>
